@@ -104,6 +104,8 @@ class Installer(object):
         self._relocateMap = self.__installArea.getRelocateMap()
         self._tmpdir = self.__installArea.getTmpDir()
         self._localRPMcache = []
+        self.downloaded_files = []
+
         if localRPMcache is not None:
             self._localRPMcache = localRPMcache
         for chained_db in chained_db_list:
@@ -258,11 +260,15 @@ class Installer(object):
                 packagelist=packagelist,
                 install_graph=install_graph)
             missing_deps.extend(missing_deps_tmp)
-        if len(missing_deps) != 0:
-            self.display_missing_deps(missing_deps)
+        # Add the missing deps into the graph to display
+        for missing in missing_deps:
+            install_graph.add_edge([missing['package'], missing['dependency']])
         install_graph.generate_dot(
             tree_mode=tree_mode,
             filename=filename)
+        # Display the missing deps
+        if len(missing_deps) != 0:
+            self.display_missing_deps(missing_deps)
 
     def getPackageListToInstall(self, packagelist,
                                 nodeps=False, ignoreInstalled=False,
@@ -555,7 +561,6 @@ class Installer(object):
         '''
         if download_only:
             ignoreInstalled = True
-
         rpmtoinstall = self.getPackageListToInstall(
             packagelist, nodeps=nodeps, ignoreInstalled=ignoreInstalled,
             nodeps_update=nodeps_update,
@@ -588,17 +593,26 @@ class Installer(object):
             if localcopy is not None:
                 if not download_only:
                     self.log.info("Using file %s from cache" % localcopy)
+                else:
+                    self.log.info("%s already downloaded." % localcopy)
                 filestoinstall[package] = (localcopy, True)
             else:
+                if download_only:
+                    self.log.info("Starting download for %s" %
+                                  package.rpmFileName())
                 self.threadPool.add_task(self._downloadfiles,
                                          [package], metadata=True,
                                          forced=download_only)
         results_download = self.threadPool.get_results()
         for result_download in results_download:
             if result_download['success']:
-                filename = result_download['result']['installlist'][0]
-                filestoinstall[filename] = (
-                    result_download['result']['files'][0], False)
+                for packages in result_download['result']:
+                    pkg = packages['package']
+                    self.downloaded_files.append(packages['path'])
+                    if download_only:
+                        self.log.info("Successful downloaded %s" %
+                                      pkg.rpmFileName())
+                    filestoinstall[pkg] = (packages['path'], False)
             else:
                 raise Exception("Error in downloading files")
 
@@ -932,12 +946,14 @@ class Installer(object):
         except:
             import urllib
 
-        files = []
+        to_return = []
         for pack in installlist:
             filename = pack.rpmFileName()
             full_filename = os.path.join(location, filename)
-            files.append(full_filename)
-
+            to_return.append({
+                'package': pack,
+                'path': full_filename
+            })
             # Checking if file is there and is ok
             needs_download = True
             if os.path.exists(full_filename):
@@ -976,11 +992,8 @@ class Installer(object):
                 if counter_download == 2:
                     raise Exception("Error in downloading file %s" % filename)
         if metadata:
-            return {
-                'installlist': installlist,
-                'files': files
-                }
-        return files
+            return to_return
+        return [f['path'] for f in to_return]
 
     def _checkRpmFile(self, full_filename):
         """ Check a specific RPM file
