@@ -20,6 +20,7 @@ import os
 import re
 import sys
 import traceback
+import shutil
 
 from os.path import abspath
 
@@ -231,6 +232,11 @@ class LbInstallClient(object):
                           action="store_true",
                           help="Queries the packages that provides the"
                                " argument")
+        parser.add_option('--dest_folder',
+                          dest="dest_folder",
+                          default=None,
+                          action="store",
+                          help="Destination folder for download mode")
         self.parser = parser
 
     def main(self):
@@ -451,7 +457,18 @@ class LbInstallClient(object):
                 self.installer.install(rpms_list, download_only=True,
                                        justdb=self.justdb,
                                        overwrite=self.overwrite,
+                                       nodeps=(not self.withdeps),
                                        dry_run=self.dry_run)
+                dest_folder = os.getcwd()
+                if opts.dest_folder:
+                    dest_folder = opts.dest_folder
+                for filename in self.installer.downloaded_files:
+                    print("Downloaded with success: %s" % filename)
+                    dest_filename = os.path.join(dest_folder,
+                                                 filename.split('/')[-1])
+                    print("Moving %s to %s" % (filename,
+                                               dest_filename))
+                    shutil.move(filename, dest_filename)
             elif mode == LbInstallClient.MODE_INSTALL:
                 for rpmname, version, release in rpms_list:
                     self.log.info("Installing RPM: %s %s %s"
@@ -504,14 +521,15 @@ Removes a RPM from the local system
 Updates a RPM from the yum repository. The rpmname
 needs to be the same as the one installed on the local system and the
 version should be grater than the local one, or if equal, the release
-should be grater.
+should be greater.
 
 %(cmd)s reinstall <rpmname> [<version> [<release>]]
 Reinstall a RPM from the yum repository. The rpmname, version and release
 needs to be the same as the one installed on the local system
 
-%(cmd)s download <rpmname> [<version> [<release>]]
-Downloads a RPM from the yum repository
+%(cmd)s [--dest_folder=folder] download <rpmname> [<version> [<release>]]
+Downloads a RPM from the yum repository. If you want to download also its
+dependencies, please use --withdeps flag.
 
 %(cmd)s query [<rpmname regexp>]
 List packages available in the repositories configured with a name
