@@ -372,7 +372,7 @@ def LbYumConsistency(configType="LHCbConfig", prog="lbyumcheck"):
     """
 
     logging.basicConfig(format="%(levelname)-8s: %(message)s")
-    logging.getLogger().setLevel(logging.WARNING)
+    logging.getLogger().setLevel(logging.INFO)
     sys.exit(LbYumConsistencyClient(configType, prog=prog).main())
 
 # Main just chooses the client and starts it
