@@ -546,18 +546,6 @@ class PackageManager(object):
                                     target)
         self.removeBackupFiles()
 
-    def getCpioFileSizes(self):
-        '''
-        Get the file sies from the CPIO archive instead of headers
-
-        :returns: the file sizes
-        '''
-        filesizes = []
-        with rpmfile.open(self._filename) as rpm:
-            for m in rpm.getmembers():
-                filesizes.append(m.size)
-        return filesizes
-
     def relocate(self, path):
         ''' Useful util if the PM is initialized with the
         proper relocation map
@@ -623,33 +611,22 @@ class PackageManager(object):
         # Restore the backup
         self.restoreFiles()
 
-    def getFileNames(self):
-        """
-        Gets the rpm payload filenames
-        :return: list of filenames
-        """
-        if self._filenames is None:
-            ret = []
-            with rpmfile.open(self._filename) as rpm:
-                for m in rpm.getmembers():
-                    ret.append((m.name, m.isdir))
-            self._filenames = ret
-        return self._filenames
-
     def getFileMetadata(self):
         '''
         Return a list with the needed info about the files in the RPM,
-        i.e. a tuple with (filename, bool(isdir), filemd5, filesize
+        i.e. a tuple with (filename, bool(isdir), filemd5, filesize)
 
         :returns: list of tuples ( filename, is directory, checksum and size)
         '''
-        tmp = list(zip(*self.getFileNames()))
-        try:
-            tmp.append(self._headers['filemd5s'])
-        except:
-            tmp.append([])
-        tmp.append(self.getCpioFileSizes())
-        return list(zip(*tmp))
+
+        # Construct a dictionary that has the key the inode value of the file
+        # and the value is represented by the checksum and the size of the file
+
+        tmp = []
+        with rpmfile.open(self._filename) as rpm:
+            for m in rpm.getmembers():
+                tmp.append((m.name, m.isdir, m.checksum,  m.size))
+        return tmp
 
     def getRelocatedFileMetadata(self):
 
