@@ -226,20 +226,24 @@ class YumChecker(object):
         install_graph = None
         missing_deps = []
         for p in packagelist:
-            install_graph, missing_deps_tmp = self._getPackagesToInstall(
-                p, packagelist=packagelist,
-                extrapackages=set(),
-                install_graph=install_graph)
-            missing_deps.extend(missing_deps_tmp)
+            try:
+                install_graph, missing_deps_tmp = self._getPackagesToInstall(
+                    p, packagelist=packagelist,
+                    extrapackages=set(),
+                    install_graph=install_graph)
+                missing_deps.extend(missing_deps_tmp)
+            except:
+                pass
         to_return = install_graph.links()
         if filter:
             to_return = []
             filter = re.compile(filter)
             for name, link in install_graph.links():
-                if filter.search(link):
-                    to_return.append((name, link))
-        from pprint import pprint
-        pprint(missing_deps)
+                try:
+                    if filter.search(link):
+                        to_return.append((name, link))
+                except:
+                    pass
         return [url for _, url in to_return]
 
     def _getPackagesToInstall(self, p,
@@ -340,12 +344,12 @@ class YumChecker(object):
 
     def _display_full_mode(self, missing_deps, export_file=None):
         # Make the display look nicer
-        max_len_n = len("Dependecy Name ")
-        max_len_v = len("Dependecy Version ")
-        max_len_r = len("Dependecy Relesae ")
+        max_len_n = len("Dependency Name ")
+        max_len_v = len("Dependency Version ")
+        max_len_r = len("Dependency Release ")
         max_len_n2 = len("Package Name ")
         max_len_v2 = len("Package Version ")
-        max_len_r2 = len("Package Relesae ")
+        max_len_r2 = len("Package Release ")
 
         for missing in missing_deps:
             req = missing['dependency']
@@ -365,16 +369,16 @@ class YumChecker(object):
             max_len_r2 = len(r) if len(r) > max_len_r2 else max_len_r2
         export_text = ""
         print("Missing dependencies of packages")
-        n = "Dependecy Name"
-        v = "Dependecy Version "
-        r = "Dependecy Relesae"
+        n = "Dependency Name"
+        v = "Dependency Version "
+        r = "Dependency Release"
         name = "%s" % n + ' ' * (max_len_n - len(n))
         version = "%s" % v + ' ' * (max_len_v - len(v))
         release = "%s" % r + ' ' * (max_len_r - len(r))
 
         n = "Package Name"
         v = "Package Version "
-        r = "Package Relesae"
+        r = "Package Release"
         name2 = "%s" % n + ' ' * (max_len_n2 - len(n))
         version2 = "%s" % v + ' ' * (max_len_v2 - len(v))
         release2 = "%s" % r + ' ' * (max_len_r2 - len(r))
