@@ -27,8 +27,8 @@ class Test(unittest.TestCase):
 
     def setUp(self):
 
-        self.filename = "BRUNEL_v51r0_x86_64_slc6_gcc49_opt-1.0.0-1.noarch.rpm"
-        url = "http://lhcbproject.web.cern.ch/lhcbproject/dist/rpm/lhcb/%s" \
+        self.filename = "A-2.0.0-1.noarch.rpm"
+        url = "http://lhcb-rpm.web.cern.ch/lhcb-rpm/lhcbdevtests/%s" \
             % self.filename
         self.url = url
         logging.basicConfig()
