@@ -37,11 +37,17 @@ class RPMInfo(object):
         self.size = file_size
         self.initial_offset = initial_offset
         self._isdir = isdir
+        self.link_target = None
+        self.checksum = None
         self._attrs = attrs
 
     @property
     def isdir(self):
-        return self._isdir
+        return self._attrs['isDir']
+
+    @property
+    def inode(self):
+        return self._attrs['ino']
 
     def __repr__(self):
         return '<RPMMember %r>' % self.name
@@ -100,10 +106,11 @@ class RPMInfo(object):
                  "isDir": 0o040000}
         attrs = dict((key, (ftype == mask))
                      for (key, mask) in masks.items())
-        attrs["ino"] = d[0]
+        attrs["ino"] = int(d[0], 16)
         attrs["mode"] = mode & 0o000777
         nlink = int(d[4], 16)
         isdir = nlink >= 2 and file_size == 0
+
         # print("CHRIS name %s size %s nlink %s isdir %s"%(name, file_size,
         #                                                  nlink, isdir))
         # print(d)
@@ -162,6 +169,9 @@ class RPMFile(object):
             g = self.gzip_file
             tmp_magic = g.read(2)
             magic = tmp_magic.decode('utf-8')
+            check_sums = dict(zip(self._headers.get('inodes', []),
+                                  self._headers.get('filemd5s', [])))
+            inodes_info = {}
             while magic:
                 if magic == '07':
                     tmp_magic = g.read(4)
@@ -169,12 +179,21 @@ class RPMFile(object):
                     member = RPMInfo._read(magic, g)
                     if member.name == 'TRAILER!!!':
                         break
-
+                    member.checksum = check_sums.get(member.inode, None)
                     # if not member.isdir:
                     # We need all members to match with the metadata info
                     _members.append(member)
+                    if member.size != 0 and member.isdir is False:
+                        inodes_info[member.inode] = member
+
                 tmp_magic = g.read(2)
                 magic = tmp_magic.decode('utf-8')
+
+                for member in _members:
+                    if member.size == 0 and member.inode in inodes_info:
+                        member.link_target = inodes_info[member.inode]
+                        member.size = member.link_target.size
+
             return _members
         return self._members
 
@@ -201,6 +220,8 @@ class RPMFile(object):
         '''
         if not isinstance(member, RPMInfo):
             member = self.getmember(member)
+        if member.link_target:
+            return self.extractfile(member.link_target)
         return _SubFile(self.gzip_file, member.file_start, member.size)
 
     _gzip_file = None
