@@ -64,6 +64,16 @@ class Test(unittest.TestCase):
                              'Not all dependencies were fulfilled',
                              'J should not be installed')
 
+    def testDownload(self):
+        self._mgr = Installer(self.siteroot, config=self.config)
+        self._mgr.install([('A', '1.0.0', '1')], download_only=True,
+                          justdb=False, overwrite=False, nodeps=True,
+                          dry_run=False)
+        self.assertEqual(len(self._mgr.downloaded_files), 1)
+        self.assertTrue(
+            'A-1.0.0-1.noarch.rpm' in self._mgr.downloaded_files[0])
+        self.assertTrue(os.path.exists(self._mgr.downloaded_files[0]))
+
     def testInstallerNoDeps(self):
         ''' Check if the instalation can be done without deps'''
         self._mgr = Installer(self.siteroot, config=self.config)
